@@ -34,6 +34,68 @@
 #include "gva-preferences.h"
 #include "gva-ui.h"
 
+static void
+mame_add_sound_option (GString *arguments)
+{
+        if (gva_mame_supports_sound ())
+        {
+                GvaMuteButton *mute_button;
+                gboolean muted;
+
+                mute_button = GVA_MUTE_BUTTON (GVA_WIDGET_MAIN_MUTE_BUTTON);
+                muted = gva_mute_button_get_muted (mute_button);
+
+                /* MAME 0.153 and earlier used "-[no]sound".
+                 * MAME 0.154 and later use "-sound auto|none". */
+                if (gva_mame_get_version_int () < 154)
+                {
+                        if (muted)
+                                g_string_append (arguments, "-nosound ");
+                        else
+                                g_string_append (arguments, "-sound ");
+                }
+                else
+                {
+                        if (muted)
+                                g_string_append (arguments, "-sound none ");
+                        else
+                                g_string_append (arguments, "-sound auto ");
+                }
+        }
+}
+
+static void
+mame_expand_string (gchar **p_string)
+{
+#if HAVE_WORDEXP_H
+        wordexp_t words;
+
+        g_return_if_fail (p_string != NULL);
+        g_return_if_fail (*p_string != NULL);
+
+        /* MAME configurations often use shell variables like $HOME
+         * in its search and output paths, so we need to expand them. */
+        if (wordexp (*p_string, &words, WRDE_NOCMD) == 0)
+        {
+                GString *buffer;
+                gsize ii;
+
+                buffer = g_string_sized_new (strlen (*p_string));
+                for (ii = 0; ii < words.we_wordc; ii++)
+                {
+                        if (ii > 0)
+                                g_string_append_c (buffer, ' ');
+                        g_string_append (buffer, words.we_wordv[ii]);
+                }
+
+                g_free (*p_string);
+                *p_string = g_string_free (buffer, FALSE);
+
+                wordfree (&words);
+        }
+#endif
+}
+
 /**
  * gva_mame_command:
  * @arguments: command line arguments
@@ -249,9 +311,6 @@ gva_mame_get_config_value (const gchar *config_key,
         gchar *config_value = NULL;
         gchar **lines;
         guint num_lines, ii;
-#ifdef HAVE_WORDEXP_H
-        wordexp_t words;
-#endif
 
         g_return_val_if_fail (config_key != NULL, NULL);
 
@@ -281,37 +340,16 @@ gva_mame_get_config_value (const gchar *config_key,
 
         g_strfreev (lines);
 
-#ifdef HAVE_WORDEXP_H
-        if (config_value == NULL)
-                goto exit;
-
-        /* MAME sometimes reports shell variables like $HOME in some of
-         * its configuration values, so we need to expand them ourselves. */
-        if (wordexp (config_value, &words, 0) == 0)
+        if (config_value != NULL)
         {
-                GString *buffer;
-                gsize ii;
-
-                buffer = g_string_sized_new (strlen (config_value));
-                for (ii = 0; ii < words.we_wordc; ii++)
-                {
-                        if (ii > 0)
-                                g_string_append_c (buffer, ' ');
-                        g_string_append (buffer, words.we_wordv[ii]);
-                }
-
-                g_free (config_value);
-                config_value = g_string_free (buffer, FALSE);
-
-                wordfree (&words);
+                mame_expand_string (&config_value);
         }
-#endif
-
-exit:
-        if (config_value == NULL)
+        else
+        {
                 g_set_error (
                         error, GVA_ERROR, GVA_ERROR_MAME,
                         _("%s: No such configuration key"), config_key);
+        }
 
         return config_value;
 }
@@ -370,12 +408,20 @@ gva_mame_get_search_paths (const gchar *config_key,
                            GError **error)
 {
         gchar *config_value;
+        gchar **search_paths;
+        guint ii;
 
         config_value = gva_mame_get_config_value (config_key, error);
         if (config_value == NULL)
                 return NULL;
 
-        return g_strsplit (config_value, ";", -1);
+        search_paths = g_strsplit (config_value, ";", -1);
+        g_return_val_if_fail (search_paths != NULL, NULL);
+
+        for (ii = 0; search_paths[ii] != NULL; ii++)
+                mame_expand_string (&search_paths[ii]);
+
+        return search_paths;
 }
 
 /**
@@ -710,31 +756,8 @@ gva_mame_run_game (const gchar *name,
                 g_string_append (arguments, "-nomaximize ");
 #endif
 
-        if (gva_mame_supports_sound ())
-        {
-                GvaMuteButton *mute_button;
-                gboolean muted;
-
-                mute_button = GVA_MUTE_BUTTON (GVA_WIDGET_MAIN_MUTE_BUTTON);
-                muted = gva_mute_button_get_muted (mute_button);
-
-                /* MAME 0.153 and earlier used "-[no]sound".
-                 * MAME 0.154 and later use "-sound auto|none". */
-                if (gva_mame_get_version_int () < 154)
-                {
-                        if (muted)
-                                g_string_append (arguments, "-nosound ");
-                        else
-                                g_string_append (arguments, "-sound ");
-                }
-                else
-                {
-                        if (muted)
-                                g_string_append (arguments, "-sound none ");
-                        else
-                                g_string_append (arguments, "-sound auto ");
-                }
-        }
+        /* This got complicated. */
+        mame_add_sound_option (arguments);
 
         g_string_append_printf (arguments, "%s", name);
 
@@ -790,16 +813,8 @@ gva_mame_record_game (const gchar *name,
                 g_string_append (arguments, "-nomaximize ");
 #endif
 
-        if (gva_mame_supports_sound ())
-        {
-                GvaMuteButton *mute_button;
-
-                mute_button = GVA_MUTE_BUTTON (GVA_WIDGET_MAIN_MUTE_BUTTON);
-                if (gva_mute_button_get_muted (mute_button))
-                        g_string_append (arguments, "-nosound ");
-                else
-                        g_string_append (arguments, "-sound ");
-        }
+        /* This got complicated. */
+        mame_add_sound_option (arguments);
 
         g_string_append_printf (arguments, "-record %s %s", inpname, name);
 
@@ -852,16 +867,8 @@ gva_mame_playback_game (const gchar *name,
                 g_string_append (arguments, "-nomaximize ");
 #endif
 
-        if (gva_mame_supports_sound ())
-        {
-                GvaMuteButton *mute_button;
-
-                mute_button = GVA_MUTE_BUTTON (GVA_WIDGET_MAIN_MUTE_BUTTON);
-                if (gva_mute_button_get_muted (mute_button))
-                        g_string_append (arguments, "-nosound ");
-                else
-                        g_string_append (arguments, "-sound ");
-        }
+        /* This got complicated. */
+        mame_add_sound_option (arguments);
 
         g_string_append_printf (arguments, "%s -playback %s", name, inpname);
 
