@@ -93,7 +93,7 @@ play_back_delete_inpfile (GtkTreeRowReference *reference)
 
         errno = 0;
         if (g_unlink (inpfile) == 0)
-                gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+                gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
         else
                 g_warning ("%s: %s", inpfile, g_strerror (errno));
 
@@ -182,10 +182,10 @@ play_back_add_input_file (GvaInputFile *input_file,
                 return;
         }
 
-        gtk_tree_store_append (GTK_TREE_STORE (game_store), &iter, NULL);
+        gtk_list_store_append (GTK_LIST_STORE (game_store), &iter);
 
-        gtk_tree_store_set (
-                GTK_TREE_STORE (game_store), &iter,
+        gtk_list_store_set (
+                GTK_LIST_STORE (game_store), &iter,
                 GVA_GAME_STORE_COLUMN_NAME, game,
                 GVA_GAME_STORE_COLUMN_COMMENT, comment,
                 GVA_GAME_STORE_COLUMN_INODE, (gint64) st.st_ino,
