@@ -271,8 +271,8 @@ log_lastplayed (GvaProcess *process,
                 model = gva_tree_view_get_model ();
                 gtk_tree_model_get_iter (model, &iter, path);
 
-                gtk_tree_store_set (
-                        GTK_TREE_STORE (model), &iter,
+                gtk_list_store_set (
+                        GTK_LIST_STORE (model), &iter,
                         GVA_GAME_STORE_COLUMN_LAST_PLAYED, &now, -1);
 
                 gtk_tree_path_free (path);
@@ -361,8 +361,8 @@ gva_action_insert_favorite_cb (GtkAction *action)
         gtk_tree_path_free (path);
         g_assert (valid);
 
-        gtk_tree_store_set (
-                GTK_TREE_STORE (model), &iter,
+        gtk_list_store_set (
+                GTK_LIST_STORE (model), &iter,
                 GVA_GAME_STORE_COLUMN_FAVORITE, TRUE, -1);
 
         gva_favorites_insert (name);
@@ -599,8 +599,8 @@ gva_action_remove_favorite_cb (GtkAction *action)
         gtk_tree_path_free (path);
         g_assert (valid);
 
-        gtk_tree_store_set (
-                GTK_TREE_STORE (model), &iter,
+        gtk_list_store_set (
+                GTK_LIST_STORE (model), &iter,
                 GVA_GAME_STORE_COLUMN_FAVORITE, FALSE, -1);
 
         gva_favorites_remove (name);
