@@ -265,6 +265,12 @@ start (void)
                         gva_error_handle (&error);
                         return;
                 }
+
+                if (!gva_db_mark_complete (&error))
+                {
+                        gva_error_handle (&error);
+                        return;
+                }
         }
         else if (gva_audit_detect_changes ())
         {
@@ -443,7 +449,6 @@ main (gint argc, gchar **argv)
         if (!gva_db_init (&error))
                 g_error ("%s", error->message);
 
-        gva_audit_init ();
         gva_main_init ();
         gva_play_back_init ();
         gva_preferences_init ();
